@@ -18,17 +18,12 @@
 #' project group, which is essentially a subfolder of the main
 #' \link[=projects_folder]{projects folder}, use \code{new_project_group()}.
 #'
-#' The folder name of the project copy created by \code{copy_project()} will be
-#' \code{new_short_title} if the user supplies a value that is different from
-#' the names of any existing directories at \code{path}. Otherwise, its folder
-#' name will be taken from its \code{id} (i.e., "p\emph{XXXX}").
-#'
 #' \code{open_project()} is a wrapper around
 #' \code{rstudioapi::\link[rstudioapi]{openProject}()}, but the user only needs
 #' to know the project's \code{id}, \code{title}, or \code{short_title} instead
 #' of the file path of the project's \emph{.Rproj} file. If there is no
 #' \emph{.Rproj} file in the project's folder, the user has the option to
-#' restore a default \emph{.Rproj} folder. If there are multiple \emph{.Rproj}
+#' restore a default \emph{.Rproj} file. If there are multiple \emph{.Rproj}
 #' files, an error is thrown.
 #'
 #' @param path A valid path string.
@@ -68,9 +63,15 @@
 #'   other functions that write and delete files.
 #'
 #' @examples
+#' #############################################################################
 #' # SETUP
-#' old_path <- Sys.getenv("PROJECTS_FOLDER_PATH")
-#' setup_projects(path = tempdir(), .Renviron_path = fs::path_temp(".Renviron"))
+#' old_home <- Sys.getenv("HOME")
+#' old_ppath <- Sys.getenv("PROJECTS_FOLDER_PATH")
+#' temp_dir <- tempfile("dir")
+#' dir.create(temp_dir)
+#' Sys.unsetenv("PROJECTS_FOLDER_PATH")
+#' Sys.setenv(HOME = temp_dir)
+#' setup_projects(path = temp_dir)
 #' #############################################################################
 #'
 #' # setting up a simple project directory tree
@@ -79,10 +80,10 @@
 #' new_project_group("prostate/clinical")
 #' new_project_group("prostate/genomics")
 #'
-#' # Wrapped in if(interactive()) because it requires interactive console input
+#' # Wrapped in if (interactive()) because it requires interactive console input
 #' # and fails automated package checking and testing.
-#' if(interactive()){
-#'   new_project(title = "Sample Authorless Project", path = "kidney")
+#' if (interactive()){
+#'   new_project(title = "Sample Authorless Project", parent_directory = "kidney")
 #'
 #'   # Moving the project folder, then moving it again.
 #'   move_project(project = 1, "kidney/genomics")
@@ -105,8 +106,7 @@
 #' }
 #' #############################################################################
 #' # CLEANUP
-#' Sys.setenv(PROJECTS_FOLDER_PATH = old_path)
-#' fs::file_delete(c(fs::path_temp("projects"), fs::path_temp(".Renviron")))
+#' Sys.setenv(HOME = old_home, PROJECTS_FOLDER_PATH = old_ppath)
 #' @importFrom rlang .data
 #' @export
 new_project_group <- function(path) {
@@ -115,12 +115,12 @@ new_project_group <- function(path) {
 
   path   <- validate_directory(path, p_path, make_directories = TRUE)
 
-  if(fs::path_ext(path) != "") {
+  if (fs::path_ext(path) != "") {
     stop("\nMust be a directory and not a file (i.e., must not have a file ",
          "extension, which is ", fs::path_ext(path), " in this case).")
   }
 
-  if(fs::dir_exists(path)) {
+  if (fs::dir_exists(path)) {
     stop("\nDirectory already exists.")
   }
 
@@ -160,7 +160,7 @@ rename_folder <- function(project,
 
   print(project_row)
 
-  if(fs::dir_exists(new_path)) {
+  if (fs::dir_exists(new_path)) {
     stop("The directory\n", new_path, "\nalready exists.",
          "\nMove or delete it, or pick a different name.")
   }
@@ -177,7 +177,7 @@ rename_folder <- function(project,
 
   project_row$path <- unclass(new_path)
 
-  if(change_short_title) {
+  if (change_short_title) {
     project_row$short_title <- new_folder_name
   }
 
@@ -280,7 +280,9 @@ move_project <- function(project,
 #' @export
 copy_project <- function(project_to_copy,
                          path,
-                         new_id           = NA,
+                         new_id          = NA,
+                         new_folder_name =
+                           paste0("p", stringr::str_pad(new_id, 4, pad = "0")),
                          new_short_title  = NA,
                          make_directories = FALSE,
                          archived         = FALSE) {
@@ -319,22 +321,32 @@ copy_project <- function(project_to_copy,
 
   old_project      <- project_row
 
-  project_row$id   <- validate_new(id         = new_id,
-                                   what       = "project",
-                                   rds_table = projects_table)
+  project_row$id <-
+    new_id <-
+    validate_new(id = new_id, what = "project", rds_table = projects_table)
 
-  if (!is.na(new_short_title)) {
-    project_row$short_title <- new_short_title
+  project_row$short_title <- new_short_title
+
+
+
+  # if (is.na(new_short_title) || any(fs::dir_ls(path) == new_short_title)) {
+  #   folder_name    <- make_project_name(project_row$id)
+  # } else {
+  #   folder_name    <- make_project_name(new_short_title, short_title = TRUE)
+  # }
+  #
+  # project_row$path <- fs::path(path, folder_name) %>% unclass()
+
+  project_row$path <-
+    make_project_path(project_name = new_folder_name, path = path)
+
+  if (fs::dir_exists(project_row$path)) {
+    stop(
+      "The directory\n", project_row$path, "\nalready exists.",
+      "\nMove or delete it, or pick a different folder_name."
+    )
   }
 
-  if (is.na(new_short_title) || any(fs::dir_ls(path) == new_short_title)) {
-    folder_name    <- make_project_name(project_row$id)
-  } else {
-    folder_name    <- make_project_name(new_short_title, short_title = TRUE)
-  }
-
-  project_row$path <- fs::path(path, folder_name) %>% unclass()
-
   print(old_project)
 
   if (fs::dir_exists(path)) {
@@ -351,7 +363,8 @@ copy_project <- function(project_to_copy,
                      "project there, so that its file path will be\n",
                      project_row$path, "\n\n? (y/n)"),
       n_msg = paste0("\nCopy not completed. To copy this project, try again ",
-                     'and enter "y"'))
+                     'and enter "y"')
+    )
 
     fs::dir_create(path)
   }
@@ -381,22 +394,22 @@ copy_project <- function(project_to_copy,
   )
   print(project_row)
 
-  new_proj_ls <- fs::dir_ls(project_row$path)
-  Rproj_path  <- new_proj_ls[fs::path_ext(new_proj_ls) == "Rproj"]
+  Rproj_path <- fs::dir_ls(project_row$path, glob = "*.Rproj")
   if (length(Rproj_path) == 1L) {
-    new_path  <- fs::path(fs::path_dir(Rproj_path), folder_name, ext = "Rproj")
+    new_path  <-
+      fs::path(project_row$path, new_folder_name, ext = "Rproj")
     fs::file_move(path = Rproj_path, new_path = new_path)
     message("\nThe .Rproj file\n", Rproj_path, "\nwas renamed to\n", new_path)
   } else if (length(Rproj_path) == 0L) {
-    message("\nNo .Rproj file found in the new project folder.")
+    warning("\nNo .Rproj file found in the new project folder.")
   } else {
-    message("\nMultiple .Rproj files found in newly created directory.",
+    warning("\nMultiple .Rproj files found in newly created directory.",
             " None have been renamed.")
   }
 
   message(
     '\nBe sure to change all instances of \"', old_folder,
-    '\" to \"', folder_name,
+    '\" to \"', new_folder_name,
     '\" as desired\n(e.g., .bib files and references to them in YAML headers).'
   )
 
@@ -465,10 +478,7 @@ open_project <- function(project, new_session = FALSE, archived = FALSE) {
       what  = "project"
     )
 
-  Rproj_path <-
-    project_row$path %>%
-    fs::dir_ls() %>%
-    `[`(fs::path_ext(.) == "Rproj")
+  Rproj_path <- fs::dir_ls(project_row$path, glob = "*.Rproj")
 
   if (length(Rproj_path) != 1L) {
 
@@ -488,13 +498,22 @@ open_project <- function(project, new_session = FALSE, archived = FALSE) {
           paste0('\nRestore a .Rproj file to the folder\n', project_row$path)
       )
 
+      default_Rproj <-
+        system.file(
+          "templates",
+          "pXXXX.Rproj",
+          package = "projects",
+          mustWork = TRUE
+        )
+
       Rproj_path <-
         fs::path(
           project_row$path,
-          make_project_name(project_row$id),
+          paste0("p", stringr::str_pad(project_row$id, width = 4L, pad = "0")),
           ext = "Rproj"
         )
-      readr::write_lines(Rproj_template, Rproj_path)
+
+      fs::file_copy(default_Rproj, Rproj_path)
 
       user_prompt(
         msg   =
